jactorch.vision.morphology
==========================

.. automodule:: jactorch.vision.morphology

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      BlackHat
      Closing
      Dilation
      Erosion
      MorphologicalGradient
      MorphologyKernelType
      MorphologyOp
      Opening
      TopHat
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      black_hat
      close
      dilate
      erode
      get_morphology_kernel
      morph_grad
      open
      top_hat
   
   

   
   
   








.. rubric:: Class BlackHat
.. autoclass:: BlackHat
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Closing
.. autoclass:: Closing
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Dilation
.. autoclass:: Dilation
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Erosion
.. autoclass:: Erosion
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MorphologicalGradient
.. autoclass:: MorphologicalGradient
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MorphologyKernelType
.. autoclass:: MorphologyKernelType
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MorphologyOp
.. autoclass:: MorphologyOp
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Opening
.. autoclass:: Opening
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class TopHat
.. autoclass:: TopHat
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: black_hat

.. autofunction:: close

.. autofunction:: dilate

.. autofunction:: erode

.. autofunction:: get_morphology_kernel

.. autofunction:: morph_grad

.. autofunction:: open

.. autofunction:: top_hat


